# 🔌 Heyoffline
Notify your users when their network goes down. Make sure they don't lose anything.

## Features

- Notify on general network outage
- Notify only when users have unsaved form field states
- Default, pretty generic, good looking styles

![](https://user-images.githubusercontent.com/34213/83430658-520d1600-a436-11ea-89da-0b6035fdf818.gif)

## Setup


### Module
NPM: [`heyoffline`](https://www.npmjs.com/package/heyoffline)

```javascript
import Heyoffline from "./dist/heyoffline.esm.js"
new Heyoffline()
```

### Browser
UNPKG: [`https://unpkg.com/heyoffline@latest/dist/heyoffline.umd.js`](https://unpkg.com/heyoffline@latest/dist/heyoffline.umd.js)

```html
<script src="dist/heyoffline.umd.js"></script>
```

```javascript
new Heyoffline({
  monitorFields: true,
  fields: ".monitoredFields"
});
```

## Options
<table>
  <tr>
    <th class="name">Name</th>
    <th class="type">Type</th>
    <th class="default">Default</th>
    <th class="desc">Description</th>
  </tr>
  <tr>
    <td>monitorFields</td>
    <td>boolean</td>
    <td>false</td>
    <td class="desc">If this option is enabled, message on network error will be shown only if a input/textarea/select/etc on the page was modified</td>
  </tr>
  <tr>
    <td>prefix</td>
    <td>string</td>
    <td>heyoffline</td>
    <td class="desc">Class prefix for generated elements</td>
  </tr>
  <tr>
    <td>noStyles</td>
    <td>boolean</td>
    <td>false</td>
    <td class="desc">Don't use the default CSS (generated by JS)</td>
  </tr>
  <tr>
    <td>disableDimiss</td>
    <td>boolean</td>
    <td>false</td>
    <td class="desc">By default the user can dismiss the warning. With this option you can hide the dismiss button.</td>
  </tr>
  <tr>
    <td>fields</td>
    <td>string</td>
    <td><code>"input, select, textarea, *[contenteditable]"</code></td>
    <td class="desc">Field elements that will be monitored for changes - see <code>monitorFields</code> option.</td>
  </tr>
  <tr>
    <td>text.offline.title</td>
    <td>string</td>
    <td>You're currently offline</td>
    <td class="desc">Heading of the modal window</td>
  </tr>
  <tr>
    <td>text.offline.content</td>
    <td>string</td>
    <td>Wait until your network comes back before continuing.</td>
    <td class="desc">Body message of the modal window</td>
  </tr>
  <tr>
    <td>text.offline.button</td>
    <td>string</td>
    <td>Dismiss</td>
    <td class="desc">Dismissal button of the modal window</td>
  </tr>
  <tr>
    <td>text.offline.icon</td>
    <td>string</td>
    <td>SVG icon</td>
    <td class="desc">Modal icon</td>
  </tr>
</table>

## Events
<table>
  <tr>
    <th class="name">Name</th>
    <th class="type">Provides</th>
    <th class="desc">Description</th>
  </tr>
  <tr>
    <td>onOnline</td>
    <td></td>
    <td>Fires then the network becomes available</td>
  </tr>
  <tr>
    <td>onOffline</td>
    <td></td>
    <td>Fires when the network disappears</td>
  </tr>
</table>

## Requirements
**Heyoffline** is **framework-agnostic** vanilla JS.

## Source code
All efforts have been made to keep the source as clean and readable as possible.

## Requirements
Heyoffline.js is released under an MIT License, so do with it what you will.
